@@ -21,8 +21,8 @@ Usage::
     list_streams_paginator: ListStreamsPaginator = client.get_paginator("list_streams")
     ```
 """
-from mypy_boto3_kinesisvideo.client import KinesisVideoClient
-from mypy_boto3_kinesisvideo.paginator import ListSignalingChannelsPaginator, ListStreamsPaginator
+from .client import KinesisVideoClient
+from .paginator import ListSignalingChannelsPaginator, ListStreamsPaginator
 
 Client = KinesisVideoClient
 
