@@ -6,9 +6,9 @@ Type annotations for kinesisvideo service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kinesisvideo.literals import APIName
+    from mypy_boto3_kinesisvideo.literals import APINameType
 
-    data: APIName = "GET_CLIP"
+    data: APINameType = "GET_CLIP"
     ```
 """
 import sys
@@ -20,19 +20,19 @@ else:
 
 
 __all__ = (
-    "APIName",
-    "ChannelProtocol",
-    "ChannelRole",
-    "ChannelType",
-    "ComparisonOperator",
+    "APINameType",
+    "ChannelProtocolType",
+    "ChannelRoleType",
+    "ChannelTypeType",
+    "ComparisonOperatorType",
     "ListSignalingChannelsPaginatorName",
     "ListStreamsPaginatorName",
-    "Status",
-    "UpdateDataRetentionOperation",
+    "StatusType",
+    "UpdateDataRetentionOperationType",
 )
 
 
-APIName = Literal[
+APINameType = Literal[
     "GET_CLIP",
     "GET_DASH_STREAMING_SESSION_URL",
     "GET_HLS_STREAMING_SESSION_URL",
@@ -41,11 +41,11 @@ APIName = Literal[
     "LIST_FRAGMENTS",
     "PUT_MEDIA",
 ]
-ChannelProtocol = Literal["HTTPS", "WSS"]
-ChannelRole = Literal["MASTER", "VIEWER"]
-ChannelType = Literal["SINGLE_MASTER"]
-ComparisonOperator = Literal["BEGINS_WITH"]
+ChannelProtocolType = Literal["HTTPS", "WSS"]
+ChannelRoleType = Literal["MASTER", "VIEWER"]
+ChannelTypeType = Literal["SINGLE_MASTER"]
+ComparisonOperatorType = Literal["BEGINS_WITH"]
 ListSignalingChannelsPaginatorName = Literal["list_signaling_channels"]
 ListStreamsPaginatorName = Literal["list_streams"]
-Status = Literal["ACTIVE", "CREATING", "DELETING", "UPDATING"]
-UpdateDataRetentionOperation = Literal["DECREASE_DATA_RETENTION", "INCREASE_DATA_RETENTION"]
+StatusType = Literal["ACTIVE", "CREATING", "DELETING", "UPDATING"]
+UpdateDataRetentionOperationType = Literal["DECREASE_DATA_RETENTION", "INCREASE_DATA_RETENTION"]
